Skip to contents

This function calculates the length of a sequence by summing the lengths of its intervals.

Usage

get_seq_length(sequence)

Arguments

sequence

A list of intervals, where each interval is expected to have start, end, and direction components.

Value

An integer representing the total length of the sequence.