Compute summary statistics from a real CNA sample
compute_observed_stats.RdApplies the same statistics used in summarise_clone() to an observed
data frame so the result can be overlaid on simulation comparison plots.
compute_observed_stats.RdApplies the same statistics used in summarise_clone() to an observed
data frame so the result can be overlaid on simulation comparison plots.