get_seq_length.Rd
This function calculates the length of a sequence by summing the lengths of its intervals.
get_seq_length(sequence)
A list of intervals, where each interval is expected to have start, end, and direction components.
start
end
direction
An integer representing the total length of the sequence.